@@ -27,13 +27,13 @@
 #define KABOUTDATA_H
 
 #include <kcoreaddons_export.h>
-#include <QtCore/QString>
-#include <QtCore/QSharedDataPointer>
+#include <QString>
+#include <QSharedDataPointer>
+#include <QVariant>
 
 template <class T> class QList;
 class QCommandLineParser;
 class QJsonObject;
-class QVariant;
 class KAboutData;
 class KPluginMetaData;
 namespace KCrash
@@ -67,6 +67,12 @@ Q_DECL_IMPORT void defaultCrashHandler(int sig);
  */
 class KCOREADDONS_EXPORT KAboutPerson
 {
+    Q_GADGET
+    Q_PROPERTY(QString name READ name CONSTANT)
+    Q_PROPERTY(QString task READ task CONSTANT)
+    Q_PROPERTY(QString emailAddress READ emailAddress CONSTANT)
+    Q_PROPERTY(QString webAddress READ webAddress CONSTANT)
+    Q_PROPERTY(QString ocsUsername READ ocsUsername CONSTANT)
     friend class KAboutData;
 public:
     /**
@@ -81,8 +87,10 @@ public:
      * @param webAddress Home page of the person.
      *
      * @param ocsUsername Open Collaboration Services username of the person.
+     *
+     * @p name default argument @since 5.53
      */
-    explicit KAboutPerson(const QString &name,
+    explicit KAboutPerson(const QString &name = QString(),
                           const QString &task = QString(),
                           const QString &emailAddress = QString(),
                           const QString &webAddress = QString(),
@@ -176,8 +184,14 @@ private:
  */
 class KCOREADDONS_EXPORT KAboutLicense
 {
+    Q_GADGET
+    Q_PROPERTY(QString name READ name CONSTANT)
+    Q_PROPERTY(QString text READ text CONSTANT)
+    Q_PROPERTY(KAboutLicense::LicenseKey key READ key CONSTANT)
+    Q_PROPERTY(QString spdx READ spdx CONSTANT)
     friend class KAboutData;
 public:
+
     /**
      * Describes the license of the software.
      */
@@ -197,6 +211,7 @@ public:
         LGPL_V3 = 7,
         LGPL_V2_1 = 8 ///< @since 5.25
     };
+    Q_ENUM(LicenseKey)
 
     /**
      * Format of the license name.
@@ -205,6 +220,7 @@ public:
         ShortName,
         FullName
     };
+    Q_ENUM(NameFormat)
 
     /**
      * Whether later versions of the license are allowed.
@@ -213,6 +229,12 @@ public:
         OnlyThisVersion,
         OrLaterVersions
     };
+    Q_ENUM(VersionRestriction)
+
+    /**
+     * @since 5.53
+     */
+    explicit KAboutLicense();
 
     /**
      * Copy constructor.  Performs a deep copy.
@@ -240,9 +262,11 @@ public:
     /**
      * Returns the license name.
      *
+     * Default argument @since 5.53
+     *
      * @return The license name as a string.
      */
-    QString name(KAboutLicense::NameFormat formatName) const;
+    QString name(KAboutLicense::NameFormat formatName = ShortName) const;
 
     /**
      * Returns the license key.
@@ -257,8 +281,8 @@ public:
      *
      * @note SPDX expression are expansive constructs. If you parse the return value, do it in a
      *   SPDX specification compliant manner by splitting on whitespaces to discard unwanted
-     *   informationor or by using a complete SPDX license expression parser.
-     * @note SPDX identifiers are case-insensitive. Do not use case-senstivie checks on the return
+     *   information or by using a complete SPDX license expression parser.
+     * @note SPDX identifiers are case-insensitive. Do not use case-sensitive checks on the return
      *   value.
      * @see https://spdx.org/licenses
      * @return SPDX license expression or QString() if the license has no identifier. Compliant
@@ -332,7 +356,7 @@ private:
  * and by the help shown on command line (see KAboutData::setupCommandLine()).
  *
  * Porting Notes: Since KDE Frameworks 5.0, the translation catalog mechanism
- * must provided by your translation framework to load the correct catalog
+ * must be provided by your translation framework to load the correct catalog
  * instead (eg: KLocalizedString::setApplicationDomain() for KI18n, or
  * QCoreApplication::installTranslator() for Qt's translation system). This
  * applies to the old setCatalogName() and catalogName() members. But see also
@@ -382,6 +406,22 @@ private:
  */
 class KCOREADDONS_EXPORT KAboutData
 {
+    Q_GADGET
+    Q_PROPERTY(QString displayName READ displayName CONSTANT)
+    Q_PROPERTY(QString productName READ productName CONSTANT)
+    Q_PROPERTY(QString componentName READ componentName CONSTANT)
+    Q_PROPERTY(QVariant programLogo READ programLogo CONSTANT)
+    Q_PROPERTY(QString shortDescription READ shortDescription CONSTANT)
+    Q_PROPERTY(QString homepage READ homepage CONSTANT)
+    Q_PROPERTY(QString bugAddress READ bugAddress CONSTANT)
+    Q_PROPERTY(QString version READ version CONSTANT)
+    Q_PROPERTY(QString otherText READ otherText CONSTANT)
+    Q_PROPERTY(QVariantList authors READ authorsVariant CONSTANT) //constant in practice as addAuthor is not exposed to Q_GADGET
+    Q_PROPERTY(QVariantList credits READ creditsVariant CONSTANT)
+    Q_PROPERTY(QVariantList translators READ translatorsVariant CONSTANT)
+    Q_PROPERTY(QVariantList licenses READ licensesVariant CONSTANT)
+    Q_PROPERTY(QString copyrightStatement READ copyrightStatement CONSTANT)
+    Q_PROPERTY(QString desktopFileName READ desktopFileName CONSTANT)
 public:
 
     /**
@@ -512,11 +552,13 @@ public:
      * Sets the property desktopFileName to "org.kde."+componentName and
      * the property organizationDomain to "kde.org".
      *
+     * Default arguments @since 5.53
+     *
      * @see setOrganizationDomain(const QByteArray&), setDesktopFileName(const QString&)
      */
-    KAboutData(const QString &componentName,
-               const QString &displayName,
-               const QString &version
+    explicit KAboutData(const QString &componentName = {},
+               const QString &displayName = {},
+               const QString &version = {}
               );
 
     /**
@@ -680,6 +722,7 @@ public:
      */
     KAboutData &setDisplayName(const QString &displayName);
 
+#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 2)
     /**
      * Obsolete method
      *
@@ -692,8 +735,9 @@ public:
      *
      * @deprecated since 5.2, use QApplication::setWindowIcon(QIcon::fromTheme()) instead.
      */
-    KCOREADDONS_DEPRECATED KAboutData &setProgramIconName(const QString &iconName); // KF6 remove this
-
+    KCOREADDONS_DEPRECATED_VERSION(5, 2, "Use QApplication::setWindowIcon")
+    KAboutData &setProgramIconName(const QString &iconName);
+#endif
     /**
      * Defines the program logo.
      *
@@ -834,13 +878,13 @@ public:
      *
      * Calling this method has no effect on the value of the desktopFileName property.
      *
-     * @note: If your program should work as a D-Bus activatable service, the base name
+     * @note If your program should work as a D-Bus activatable service, the base name
      * of the D-Bus service description file or of the desktop file you install must match
      * the D-Bus "well-known name" for which the program will register.
      * For example, KDBusService will use a name created from the reversed organization domain
      * with the component name attached, so for an organization domain "bar.org" and a
      * component name "foo" the name of an installed D-Bus service file needs to be
-     * "org.bar.foo.service" or the the name of the installed desktop file "org.bar.foo.desktop"
+     * "org.bar.foo.service" or the name of the installed desktop file "org.bar.foo.desktop"
      * (and the desktopFileName property accordingly set to "org.bar.foo").
      * For still supporting the deprecated start of services via KToolInvocation,
      * the desktop file needs to have an entry with the key "X-DBUS-ServiceName"
@@ -897,6 +941,8 @@ public:
      */
     const char *internalProgramName() const;
 
+// Not using KCOREADDONS_ENABLE_DEPRECATED_SINCE because KXmlGui and KConfigWidgets need this, for compat
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
     /**
      * Returns the program's icon name.
      *
@@ -905,7 +951,9 @@ public:
      *
      * This is mostly for compatibility, given that setProgramIconName is deprecated.
      */
+    KCOREADDONS_DEPRECATED_VERSION(5, 2, "Use QApplication::windowIcon")
     QString programIconName() const;
+#endif
 
     /**
      * Returns the program logo image.
@@ -1115,6 +1163,10 @@ public:
     QString desktopFileName() const;
 
 private:
+    QVariantList licensesVariant() const;
+    QVariantList authorsVariant() const;
+    QVariantList creditsVariant() const;
+    QVariantList translatorsVariant() const;
 
     friend void KCrash::defaultCrashHandler(int sig);
     static const KAboutData *applicationDataPointer();
@@ -1123,5 +1175,9 @@ private:
     Private *const d;
 };
 
+Q_DECLARE_METATYPE(KAboutData)
+Q_DECLARE_METATYPE(KAboutLicense)
+Q_DECLARE_METATYPE(KAboutPerson)
+
 #endif
 
